@@ -11,13 +11,11 @@ import numpy as np
 t = np.linspace(0, 0.01, 1000)
 vr = cct.R.v.evaluate(t)
 
-from matplotlib.pyplot import figure, savefig
-fig = figure()
-ax = fig.add_subplot(111)
+from matplotlib.pyplot import subplots, savefig
+fig, ax = subplots(1)
 ax.plot(t, vr, linewidth=2)
 ax.set_xlabel('Time (s)')
 ax.set_ylabel('Resistor voltage (V)')
 ax.grid(True)
 
-
 savefig('circuit-VRLC1-vr.png')
