@@ -5,6 +5,8 @@ Copyright 2019--2021 Michael Hayes, UCECE
 """
 
 # SymPy symbols to exclude.  It might be easier to add the ones we want...
+# 'I' is removed to avoid conflict with oneport current source and
+# since `j` is used instead.
 excludes = ['I', 'C', 'O', 'S', 'N', 'E', 'E1', 'Q', 'beta', 'gamma', 'zeta',
             'Le', 'Lt', 'Ge', 'Gt', 'Ci']
 
@@ -30,7 +32,7 @@ functions = ('heaviside', 'diracdelta', 'conjugate', 'sqrt', 'exp',
              'log', 'log10', 'sin', 'cos', 'tan', 'cot' 'asin',
              'acos', 'atan', 'atan2', 'acot', 'sinh', 'cosh', 'tanh', 'asinh',
              'acosh', 'atanh', 'gcd', 'abs', 'unitimpulse', 'arg', 'sign',
-             'rect', 'sinc', 'sincn', 'sincu', 'trap', 'tri')
+             'rect', 'sinc', 'sincn', 'sincu', 'trap', 'tri', 'dtrect', 'dtsign')
 
 subscripts = ('in', 'out', 'ref', 'rms', 'load', 'source', 'avg',
               'mean', 'peak', 'pk', 'pk-pk', 'pp', 'min', 'max', 'src', 'bat',
@@ -71,3 +73,8 @@ printing_order = None
 colours = {'startnode': 'green', 'endnode': 'green',
            'assignednode': 'Orchid1', 'unassignednode': 'SkyBlue1',
            'fixednode': 'Yellow', 'fixededge': 'Red', 'stretchedge': 'black'}
+
+# Definition of H(0).  With H(0) = 0.5 then sgn(0) = 0 as expected by SymPy and NumPy
+heaviside_zero = 0.5
+# This is the common convention.
+unitstep_zero = 1
