@@ -87,12 +87,12 @@ class ExpressionClassBuilder(dict):
         docstring = '%s-domain %s (units %s).' % (domainclass.domain_label,
                                                   quantity, unitsstring)
 
-        suffix = 'Expression'
-        name = domainclass.__name__.replace(suffix, quantityclass.quantity.capitalize())
+        name = domainclass.__name__.replace('Expression', quantityclass.quantity.capitalize())
+        name = name.replace('Sequence', quantityclass.quantity.capitalize() + 'Sequence')
             
         newclass = type(name, (quantityclass, domainclass),
-                            {'__doc__': docstring,
-                             '_default_units': units_mapping[unitsstring]})
+                        {'__doc__': docstring,
+                         '_default_units': units_mapping[unitsstring]})
         self[quantity] = newclass
 
         #print('Created %s %s' % (self.domain, quantity))
