@@ -9,6 +9,7 @@ Copyright 2020--2021 Michael Hayes, UCECE
 import sympy as sym
 from sympy.core import S, Integer
 from sympy.core.logic import fuzzy_not
+from .config import unitstep_zero
 
 class UnitImpulse(sym.Function):
 
@@ -31,10 +32,16 @@ class UnitStep(sym.Function):
     is_integer = True
     
     @classmethod
-    def eval(cls, nval):
+    def eval(cls, nval, zero=None):
         """
-        Evaluates the discrete unit step function.
+        Evaluates the discrete unit step function.   This is defined
+        as 1 for n >= 0 and 0 otherwise.  
         """
+
+        if nval.is_zero:
+            if zero is None:
+                zero = unitstep_zero
+            return zero
         
         if nval.is_nonnegative:
             return S.One
@@ -60,6 +67,39 @@ class rect(sym.Function):
         x = self.args[0]
         return sym.Heaviside(x + S.Half) - sym.Heaviside(x - S.Half)
 
+
+class dtrect(sym.Function):
+
+    @classmethod
+    def eval(cls, val):
+        """
+        Evaluates the rectangle function for discrete-time signals.
+        """
+
+        if val.is_Number:
+            if val < -0.5 or val >= 0.5:
+                return S.Zero
+            return S.One
+
+    def rewrite(self, *args, **hints):
+
+        x = self.args[0]
+        return UnitStep(x + S.Half) - UnitStep(x - S.Half)
+
+    
+class dtsign(sym.Function):
+
+    @classmethod
+    def eval(cls, val):
+        """
+        Evaluates the signum function for discrete-time signals.
+        """
+
+        if val.is_Number:
+            if val >= 0:
+                return S.One
+            return S.Zero
+
         
 class sincn(sym.Function):
     
@@ -108,7 +148,6 @@ class psinc(sym.Function):
         """
         Evaluates the periodic sinc function.
         """
-
         if val.is_Number:
             if val == 0:
                 return S.One
