@@ -116,6 +116,7 @@ class FourierDomainExpression(FourierDomain, Expr):
         `xscale` - the x-axis scaling, say for plotting as ms
         `yscale` - the y-axis scaling, say for plotting mV
         `norm` - use normalized frequency
+        `dbmin` - the smallest value to plot in dB (default -120)
         in addition to those supported by the matplotlib plot command.
         
         The plot axes are returned.  This is a tuple for magnitude/phase or
@@ -142,27 +143,37 @@ class FourierDomainExpression(FourierDomain, Expr):
         plot (but without the straight line approximations).  fvector
         specifies the frequencies.  If it is a tuple (f1, f2), it sets
         the frequency limits.   Since a logarithmic frequency scale is used,
-        f1 must be greater than 0."""
+        f1 must be greater than 0.
+
+        For more info, see `plot`.
+        """
         
         from .plot import plot_bode
-        from .sym import pi, fsym
-
         return plot_bode(self, fvector, **kwargs)
 
-    def nyquist_plot(self, fvector=None, **kwargs):
-        """Plot frequency response as a Nyquist plot (real part versus
-        imaginary part).  fvector specifies the frequencies.  If it is
+    def nyquist_plot(self, fvector=None, log_frequency=True, **kwargs):
+        """Plot frequency response as a Nyquist plot (imaginary part versus
+        real part).  fvector specifies the frequencies.  If it is
         a tuple (f1, f2), it sets the frequency limits as (f1, f2).
 
-        The points on the plot are geometrically spaced so f1 must be greater
-        than zero.  By default, the mirrored plot for negative frquencies is 
-        shown.  This can be disabled with `mirror = False`.
+        `npoints` set the number of plotted points.
 
-        The unit circle is shown by default.  This can be disabled with `unitcircle = False`.
+        The unit circle is shown by default.  This can be disabled with `unitcircle=False`.
         """        
 
         from .plot import plot_nyquist
-        return plot_nyquist(self, fvector, **kwargs)        
+        return plot_nyquist(self, fvector, log_frequency=log_frequency, **kwargs)
+
+    def nichols_plot(self, fvector=None, log_frequency=True, **kwargs):
+        """Plot frequency response as a Nichols plot (dB part versus
+        phase).  fvector specifies the frequencies.  If it is
+        a tuple (f1, f2), it sets the frequency limits as (f1, f2).
+
+        `npoints` set the number of plotted points.
+        """        
+
+        from .plot import plot_nichols
+        return plot_nichols(self, fvector, log_frequency=log_frequency, **kwargs)    
     
     
 def fexpr(arg, **assumptions):
