@@ -32,7 +32,7 @@ class FourierTransformer(BilateralForwardTransformer):
 
     name = 'Fourier transform'
 
-    def key(self, expr, t, f, **assumptions):
+    def key(self, expr, t, f, **kwargs):
         return expr, t, f
 
     def simplify_term(self, expr, var):
@@ -72,7 +72,7 @@ class FourierTransformer(BilateralForwardTransformer):
         if shift != 0:
             if self.is_inverse:
                 shift = -shift
-                result = result * exp(2 * I * pi * f * shift / scale)
+            result = result * exp(2 * I * pi * f * shift / scale)
 
         return result
 
@@ -164,16 +164,12 @@ class FourierTransformer(BilateralForwardTransformer):
         if len(exprs) == 1:
             return result * const
 
-        dummy = 'tau' if self.is_inverse else 'nu'
-
         for m in range(len(exprs) - 1):
-            if m == 0:
-                nu = sympify(dummy)
-            else:
-                nu = sympify(dummy + '_%d' % m)
-                expr2 = self.term(exprs[m + 1], t, f)
-                result = Integral(result.subs(f, f - nu) * expr2.subs(f, nu),
-                                      (nu, -oo, oo))
+            nu = self.dummy_var(expr, 'tau' if self.is_inverse else 'nu',
+                                level=m, real=True)
+            expr2 = self.term(exprs[m + 1], t, f)
+            result = Integral(result.subs(f, f - nu) * expr2.subs(f, nu),
+                              (nu, -oo, oo))
 
         return result * const
 
@@ -261,11 +257,21 @@ class FourierTransformer(BilateralForwardTransformer):
             elif other.is_Function and other.func == trap and other.args[0].has(t):
                 scale, shift = scale_shift(other.args[0], t)
                 alpha = other.args[1]
-                # Chck for rect
+                # Check for rect
                 if alpha == 0:
                     return const1 * sincn(f / scale) * exp(I * 2 * pi * sf /scale * shift) / abs(scale)
 
-                return alpha * const1 * sincn(f / scale) * sincn(alpha * f / scale) * exp(I * 2 * pi * sf /scale * shift) / abs(scale)        
+                return alpha * const1 * sincn(f / scale) * sincn(alpha * f / scale) * exp(I * 2 * pi * sf /scale * shift) / abs(scale)
+
+            # 
+            # factor = other.factor()
+            # const2, factor2 = factor_const(factor, t)
+            # if factor2.is_Pow and factor2.args[1] == -2:
+            #     foo = factor2.args[0]
+            #     a = foo.coeff(t, 1)                                
+            #     b = foo.coeff(t, 0)
+            #     if a != 0:
+            #         return const1 * const2 * f * exp(-b * 2 *pi * f / a) * sign(f) / (2 * pi)
 
             # Sympy incorrectly gives exp(-a * t) instead of exp(-a * t) *
             # Heaviside(t)
@@ -319,13 +325,14 @@ class FourierTransformer(BilateralForwardTransformer):
             expr = expr.replace(lambda expr: expr.is_Function and expr.func == cos,
                                 lambda expr: expr.rewrite(exp))
 
+        expr = expr.expand()
         return expr
 
     
 fourier_transformer = FourierTransformer()
 
 
-def FT(expr, t, f, **assumptions):
+def FT(expr, t, f, **kwargs):
     """Compute bilateral Fourier transform of expr.
 
     Undefined functions such as v(t) are converted to V(f)
@@ -333,10 +340,10 @@ def FT(expr, t, f, **assumptions):
     This also handles some expressions that do not really have a Fourier
     transform, such as a, cos(a * t), sin(a * t), exp(I * a * t)."""    
     
-    return fourier_transformer.transform(expr, t, f, **assumptions)
+    return fourier_transformer.transform(expr, t, f, **kwargs)
 
 
-def fourier_transform(expr, t, f, **assumptions):
+def fourier_transform(expr, t, f, **kwargs):
     """Compute bilateral Fourier transform of expr.
 
     Undefined functions such as v(t) are converted to V(f)
@@ -344,4 +351,4 @@ def fourier_transform(expr, t, f, **assumptions):
     This also handles some expressions that do not really have a Fourier
     transform, such as a, cos(a * t), sin(a * t), exp(I * a * t)."""    
     
-    return fourier_transformer.transform(expr, t, f, **assumptions)
+    return fourier_transformer.transform(expr, t, f, **kwargs)
