@@ -7,15 +7,26 @@ Copyright 2014--2021 Michael Hayes, UCECE
 from .units import u as uu
 import sympy as sym
 
-__all__ = ('conjugate', 'sqrt', 'exp', 'log', 'log10',
-           'sin', 'cos', 'tan', 'cot',
-           'asin', 'acos', 'atan', 'atan2', 'acot',
-           'sinh', 'cosh', 'tanh', 'coth',
-           'asinh', 'acosh', 'atanh', 'acoth',
-           'gcd', 'sign', 'diff', 'integrate',
-           'u', 'H', 'heaviside', 'Heaviside', 'delta', 'DiracDelta',
-           'ui', 'us', 'unitimpulse', 'unitstep', 'UnitImpulse', 'UnitStep',
-           'rect', 'sinc', 'sincn', 'sincu', 'psinc', 'tri', 'trap', 'Sum')
+__all__ = ('conjugate', 'sqrt', 'exp', 'log', 'log10', 'sin', 'cos',
+           'tan', 'cot', 'asin', 'acos', 'atan', 'atan2', 'acot',
+           'sinh', 'cosh', 'tanh', 'coth', 'asinh', 'acosh', 'atanh',
+           'acoth', 'gcd', 'sign', 'diff', 'integrate', 'u', 'H',
+           'heaviside', 'Heaviside', 'delta', 'DiracDelta', 'ui',
+           'us', 'unitimpulse', 'unitstep', 'UnitImpulse', 'UnitStep',
+           'rect', 'sinc', 'sincn', 'sincu', 'psinc', 'tri', 'trap',
+           'Sum', 'dtrect', 'dtsign', 'Piecewise', 'Eq', 'Ne',
+           'Lt', 'Le', 'Gt', 'Ge')
+
+from .extrafunctions import UnitImpulse as UnitImpulse1
+from .extrafunctions import UnitStep as UnitStep1
+from .extrafunctions import sincn as sincn1
+from .extrafunctions import sincu as sincu1
+from .extrafunctions import psinc as psinc1
+from .extrafunctions import rect as rect1
+from .extrafunctions import dtrect as dtrect1
+from .extrafunctions import dtsign as dtsign1
+from .extrafunctions import tri as tri1
+from .extrafunctions import trap as trap1
 
 
 class Function(object):
@@ -31,22 +42,42 @@ class Function(object):
 
     def __call__(self, *args):
 
-        e_args = [expr(arg) for arg in args]
-        
-        cls = e_args[0].__class__
+        func = self.expr
+            
+        e_args = list(map(expr, args))
 
-        # Handle cases like atan2(1, omega)
-        if len(e_args) > 1:
-            if e_args[0].is_constant:
-                cls = e_args[1].__class__                
-        
-        result = self.expr(*[arg.expr for arg in e_args])
+        if func == sym.Piecewise:
+            cls = e_args[0][0].__class__
+        else:
+            cls = e_args[0].__class__
+            
+            # Handle cases like atan2(1, omega)
+            if len(e_args) > 1:
+                if e_args[0].is_constant:
+                    cls = e_args[1].__class__                
+
+        try:
+            if cls.is_discrete_time_domain or cls.is_discrete_fourier_domain:
+
+                mapping = {sym.Heaviside: UnitStep1,
+                           sym.DiracDelta: UnitImpulse1,
+                           rect1: dtrect,
+                           sym.sign: dtsign}
+                
+                for old, new in mapping.items():
+                    if func is old:
+                        func = new
+                        break
+        except:
+            pass
+                
+        result = func(*delcapify(e_args))
 
         result = cls(result)        
             
-        if (e_args[0].is_phase and
-            self.expr in (sym.sin, sym.cos, sym.tan, sym.cot, sym.exp,
-                          sym.sinh, sym.cosh, sym.tanh, sym.coth)):
+        if (self.expr in (sym.sin, sym.cos, sym.tan, sym.cot, sym.exp,
+                          sym.sinh, sym.cosh, sym.tanh, sym.coth)
+            and e_args[0].is_phase):
             result.part = ''
         elif self.expr in (sym.atan, sym.atan2):
             result.units = uu.rad
@@ -145,63 +176,29 @@ u = H = heaviside = Heaviside = Function(sym.Heaviside)
 
 delta = DiracDelta = Function(sym.DiracDelta)
 
+Piecewise = Function(sym.Piecewise)
 
-def _ex(expr):
-    """De-lcapify expression."""
-    
-    if hasattr(expr, 'expr'):
-        return expr.expr
-    elif isinstance(expr, tuple):
-        return tuple([_ex(arg) for arg in expr])
-    elif isinstance(expr, list):
-        return [_ex(arg) for arg in expr]
-    elif isinstance(expr, dict):
-        ret = {}
-        for key, val in expr.items():
-            ret[_ex(key)] = _ex(val)
-        return ret
-    return expr
+Eq = Function(sym.Eq)
 
+Ne = Function(sym.Ne)
 
-class Eq(sym.Eq):
-    def __new__(cls, lhs, rhs=None, **options):
-        return expr(super(Eq, cls).__new__(cls, _ex(lhs), _ex(rhs), **options))
+Lt = Function(sym.Lt)
 
+Le = Function(sym.Le)
 
-class Add(sym.Add):
-    def __new__(cls, op1, op2, **options):
-        return expr(super(Add, cls).__new__(cls, _ex(op1), _ex(op2), **options))
+Gt = Function(sym.Gt)
 
-    
-class Mul(sym.Mul):
-    def __new__(cls, op1, op2, **options):
-        return expr(super(Mul, cls).__new__(cls, _ex(op1), _ex(op2), **options))
+Ge = Function(sym.Ge)
 
-    
-class MatAdd(sym.MatAdd):
-    def __new__(cls, op1, op2, **options):
-        return expr(super(MatAdd, cls).__new__(cls, _ex(op1), _ex(op2), **options))
+Add = Function(sym.Add)
 
-    
-class MatMul(sym.MatMul):
-    def __new__(cls, op1, op2, **options):
-        return expr(super(MatMul, cls).__new__(cls, _ex(op1), _ex(op2), **options))
+Mul = Function(sym.Mul)
 
+MatAdd = Function(sym.MatAdd)
 
-class Sum(sym.Sum):
-    def __new__(cls, op1, op2, **options):
-        return expr(super(Sum, cls).__new__(cls, _ex(op1), _ex(op2), **options))
-    
-
-from .extrafunctions import UnitImpulse as UnitImpulse1
-from .extrafunctions import UnitStep as UnitStep1
-from .extrafunctions import sincn as sincn1
-from .extrafunctions import sincu as sincu1
-from .extrafunctions import psinc as psinc1
-from .extrafunctions import rect as rect1
-from .extrafunctions import tri as tri1
-from .extrafunctions import trap as trap1
+MatMul = Function(sym.MatMul)
 
+Sum = Function(sym.Sum)
 
 ui = unitimpulse = UnitImpulse = Function(UnitImpulse1)
 
@@ -209,6 +206,10 @@ us = unitstep = UnitStep = Function(UnitStep1)
 
 rect = Function(rect1)
 
+dtrect = Function(dtrect1)
+
+dtsign = Function(dtsign1)
+
 sinc = SincnFunction(sincn1)
 
 sincn = SincnFunction(sincn1)
@@ -222,4 +223,4 @@ tri = Function(tri1)
 trap = Function(trap1)
  
 
-from .expr import Expr, expr
+from .expr import Expr, expr, delcapify
