@@ -10,8 +10,9 @@ from .domains import DiscreteFourierDomain
 from .inverse_fourier import inverse_fourier_transform
 from .functions import exp
 from .sym import j, oo, pi
-from .seqexpr import SequenceExpression
 from .dsym import nsym, ksym, zsym
+from .seqexpr import SequenceExpression
+from .kseq import DiscreteFourierDomainSequence
 from .inverse_dft import IDFT
 from sympy import Sum
 
@@ -21,6 +22,7 @@ class DiscreteFourierDomainExpression(DiscreteFourierDomain, SequenceExpression)
     """Discrete Fourier domain expression or symbol."""
 
     var = ksym
+    seqcls = DiscreteFourierDomainSequence    
 
     def __init__(self, val, **assumptions):
 
@@ -71,20 +73,30 @@ class DiscreteFourierDomainExpression(DiscreteFourierDomain, SequenceExpression)
 
         """
 
-        from .plot import plot_frequency
-        return plot_frequency(self, kvector, **kwargs)
+        if kvector is None:
+            kvector = (0, 20)
+        
+        from .plot import plot_sequence
+        return plot_sequence(self, kvector, **kwargs)
 
     def IDFT(self, N=None, evaluate=True):
+        """Determine inverse DFT.  
+        
+        `N` needs to be a positive integer symbol or a str specifying
+        the extent of the inverse DFT.  By default `N` is defined as
+        'N'."""
 
-        from .nexpr import n
+        from .sym import symsymbol
 
         if N is None:
-            from .sym import symsymbol
-
-            N = symsymbol('N', integer=True, positive=True)            
+            N = symsymbol('N', integer=True, positive=True)
+        elif isinstance(N, str):
+            N = symsymbol(N, integer=True, positive=True)            
 
         result = IDFT(self.expr, ksym, nsym, N, evaluate=evaluate)
-        return self.change(result, domain='discrete time')
+        result = self.change(result, domain='discrete time')        
+        result = result.simplify_unit_impulse()
+        return result
     
     def ZT(self, **assumptions):
         return self.IDFT().ZT(**assumptions)
@@ -108,6 +120,6 @@ def kexpr(arg, **assumptions):
 
 from .expressionclasses import expressionclasses
 
-classs = expressionclasses.register('discrete fourier', DiscreteFourierDomainExpression)
+expressionclasses.register('discrete fourier', DiscreteFourierDomainExpression)
 
 k = DiscreteFourierDomainExpression('k', integer=True)
