@@ -1,7 +1,7 @@
 """
-This module implements a quantity for the SymPy Matrix class.
+This module implements the Lcapy Matrix class.
 
-Copyright 2019--2020 Michael Hayes, UCECE
+Copyright 2019--2021 Michael Hayes, UCECE
 """
 
 import sympy as sym
@@ -17,7 +17,7 @@ def msympify(expr):
 
     if isinstance(expr, Expr):
         # Bye bye Lcapy type information...
-        return expr.expr
+        return expr.sympy
     return sym.sympify(expr)
         
         
@@ -40,6 +40,9 @@ class Matrix(sym.Matrix):
 
     def __getitem__(self, key):
 
+        # This wraps elements as an Expr.  It is called
+        # for each element when a Matrix is printed.
+
         item = super(Matrix, self).__getitem__(key)
 
         # The following line is to handle slicing used
@@ -50,7 +53,7 @@ class Matrix(sym.Matrix):
         if hasattr(self, '_typewrap'):
             return self._typewrap(item)
 
-        return expr(item)
+        return expr(item, rational=False)
 
     def _repr_pretty_(self, p, cycle):
         """This is used by jupyter notebooks to display an expression using
@@ -73,6 +76,12 @@ class Matrix(sym.Matrix):
 
         return latex(self, **kwargs)
 
+    def pdb(self):
+        """Enter the python debugger."""
+        
+        import pdb; pdb.set_trace()
+        return self
+
     def canonical(self):
         
         return self
@@ -99,12 +108,12 @@ class Matrix(sym.Matrix):
     def replace(self, query, value, map=False, simultaneous=True, exact=None):
 
         try:
-            query = query.expr
+            query = query.sympy
         except:
             pass
 
         try:
-            value = value.expr
+            value = value.sympy
         except:
             pass        
 
@@ -118,14 +127,13 @@ class Matrix(sym.Matrix):
     def subs(self, *args, **kwargs):
         """Substitute variables in expression, see sympy.subs for usage."""
 
-        f = lambda x: expr(x).subs(*args, **kwargs).expr
+        f = lambda x: expr(x).subs(*args, **kwargs).sympy
         return self.applyfunc(f)
 
     @property    
-    def conjugate(self):
-        """For compatilibility with Expr conjugate is an attribute, unlike
-        with SymPy."""
-        return self._new(self.rows, self.cols, [x.conjugate for x in self])
+    def conj(self):
+        """Complex conjugate; for compatilibility with Expr conj is an attribute."""
+        return self._new(self.rows, self.cols, [x.conj for x in self])
     
     @property
     def symbols(self):
@@ -133,7 +141,49 @@ class Matrix(sym.Matrix):
         symbols = {}
         for elt in self:
             symbols.update(expr(elt).symbols)
-        return symbols        
+        return symbols
+
+    @property
+    def sympy(self):
+
+        return sym.Matrix(self.rows, self.cols, [x.sympy for x in self])
+
+    @property
+    def expr(self):
+        return self.sympy
+
+    @property
+    def is_complex(self):
+
+        for x in self:
+            if x.is_complex:
+                return True
+        return False
+    
+    def evaluate(self, arg=None):
+        """Evaluate matrix at arg.  `arg` may be a scalar.
+        The result is a NumPy float or complex array.
+
+        There can be only one or fewer undefined variables in the expression.
+        This is replaced by `arg` and then evaluated to obtain a result.
+        """
+                
+        from numpy import empty
+
+        dtype = float
+        if self.is_complex:
+            dtype = complex
+        result = empty((self.rows, self.cols), dtype=dtype)
+
+        for i in range(self.rows):
+            for j in range(self.cols):
+                result[i, j] = self[i, j].evaluate(arg)
+        return result
+
+    @property
+    def numpy(self):
+        """Return NumPy array; not a NumPy matrix."""
+        return self.evaluate()
     
 
 def matrix(mat):
@@ -196,5 +246,29 @@ def matrix_inverse(M, method='default'):
 
     return M.inv(method=method)
 
+    def canonical(self):
+
+        return self.applyfunc(self._typewrap.canonical)
+
+    def general(self):
+
+        return self.applyfunc(self._typewrap.general)
+
+    def mixedfrac(self):
+
+        return self.applyfunc(self._typewrap.mixedfrac)
+
+    def partfrac(self):
+
+        return self.applyfunc(self._typewrap.partfrac)
+
+    def timeconst(self):
+
+        return self.applyfunc(self._typewrap.timeconst)   
+
+    def ZPK(self):
+
+        return self.applyfunc(self._typewrap.ZPK)    
+
     
 from .expr import Expr, expr
