@@ -47,7 +47,7 @@ class Cpt(ImmittanceMixin):
     add_series = False
     add_parallel = False    
     equipotential_nodes = ()
-    
+    is_transformer = False
 
     def __init__(self, cct, namespace, defname, name, cpt_type, cpt_id, string,
                  opts_string, nodes, keyword, *args):
@@ -1134,6 +1134,7 @@ class K(Dummy):
                                  opts_string, nodes, keyword, *args)
 
     def _stamp(self, cct):
+        from .sym import ssym
 
         if cct.kind == 'dc':
             return
@@ -1151,7 +1152,7 @@ class K(Dummy):
 
         if cct.kind in ('s', 'ivp', 'laplace'):
             # FIXME, generalise for other domains...
-            ZM = K.expr * sym.sqrt(ZL1 * ZL2 / s**2) * s
+            ZM = K.expr * sym.sqrt(ZL1 * ZL2 / ssym**2) * ssym
         else:
             ZM = K.expr * sym.sqrt(ZL1 * ZL2)
             
@@ -1390,6 +1391,7 @@ class TF(Cpt):
     """Transformer"""    
 
     need_branch_current = True
+    is_transformer = True    
 
     def _stamp(self, cct):
 
@@ -1402,7 +1404,9 @@ class TF(Cpt):
         if n2 >= 0:
             cct._B[n2, m] -= 1
             cct._C[m, n2] -= 1
-        
+
+        # Voltage gain = 1 / a where a = N_1 / N_2
+        # is the turns-ratio.
         T = self.cpt.alpha.expr
 
         if n3 >= 0:
