@@ -16,7 +16,7 @@ from .schematic import Schematic
 from .symbols import j, s, omega
 from .attrdict import AttrDict
 from .netfile import NetfileMixin
-from .statespace import StateSpace
+from .statespacemaker import StateSpaceMaker
 from .voltage import Vname
 from .current import Iname, current
 from .simulator import Simulator
@@ -86,6 +86,18 @@ class NetlistMixin(object):
         import pdb; pdb.set_trace()
         return self
 
+    @property
+    def params(self):
+        """Return list of symbols used as arguments in the circuit."""
+
+        symbols = self.symbols
+        params = []
+        for elt in self.elements.values():
+            for arg in elt.args:
+                if arg in symbols and arg not in params:
+                    params.append(arg)
+        return params
+    
     @property
     def symbols(self):
         """Return dictionary of symbols defined in the circuit."""
@@ -1460,16 +1472,20 @@ class NetlistMixin(object):
         self._sim = Simulator(self)
         return self._sim
     
-    @property
-    def ss(self):
+    def state_space(self):
         """Generate state-space representation."""        
 
         if hasattr(self, '_ss'):
             return self._ss
 
-        self._ss = StateSpace(self)
+        self._ss = StateSpaceMaker().from_circuit(self)
         return self._ss
 
+    @property
+    def ss(self):
+        """Generate state-space representation."""        
+        return self.state_space()
+    
     def replace(self, oldname, newname):
         """Replace component.
         
@@ -1710,6 +1726,36 @@ class NetlistMixin(object):
 
         return self.analysis['reactances']
 
+    @property
+    def transformers(self):
+        """Return dictionary of transformers."""
+
+        return self.analysis['transformers']
+
+    @property
+    def capacitors(self):
+        """Return dictionary of capacitors."""
+
+        return self.analysis['capacitors']
+
+    @property
+    def inductors(self):
+        """Return dictionary of inductors."""
+
+        return self.analysis['inductors']
+
+    @property
+    def voltage_sources(self):
+        """Return dictionary of voltage_sources."""
+
+        return self.analysis['voltage_sources']
+
+    @property
+    def current_sources(self):
+        """Return dictionary of current_sources."""
+
+        return self.analysis['current_sources']                    
+
     @property
     def ics(self):
         """Return dictionary of components with initial conditions."""
@@ -1799,6 +1845,11 @@ class NetlistMixin(object):
         dependent_sources = []        
         control_sources = []
         reactances = []
+        transformers = []
+        capacitors = []
+        inductors = []
+        voltage_sources = []
+        current_sources = []
         ics = []
         
         for eltname, elt in self.elements.items():
@@ -1826,7 +1877,17 @@ class NetlistMixin(object):
                 dependent_sources.append(eltname)
             if elt.reactive:
                 reactive = True
-                reactances.append(eltname)                
+                reactances.append(eltname)
+            if elt.is_transformer:
+                transformers.append(eltname)
+            elif elt.is_capacitor:
+                capacitors.append(eltname)
+            elif elt.is_inductor:
+                inductors.append(eltname)
+            elif elt.is_voltage_source:
+                voltage_sources.append(eltname)
+            elif elt.is_current_source:
+                current_sources.append(eltname)                                
 
         num_sources = len(independent_sources)
                     
@@ -1839,6 +1900,11 @@ class NetlistMixin(object):
         analysis['has_s'] = has_s
         analysis['has_transient'] = has_transient
         analysis['reactances'] = reactances
+        analysis['transformers'] = transformers
+        analysis['capacitors'] = capacitors
+        analysis['inductors'] = inductors
+        analysis['voltage_sources'] = voltage_sources
+        analysis['current_sources'] = current_sources
         analysis['ics'] = ics         
         analysis['dependent_sources'] = dependent_sources        
         analysis['independent_sources'] = independent_sources
