@@ -7,23 +7,24 @@ Copyright 2020--2021 Michael Hayes, UCECE
 
 from __future__ import division
 from .domains import DiscreteTimeDomain
-from .seqexpr import SequenceExpression
 from .sequence import Sequence
 from .functions import exp
 from .sym import j, oo, pi, fsym, oo
 from .dsym import nsym, ksym, zsym, dt
 from .ztransform import ztransform
 from .dft import DFT
+from .seqexpr import SequenceExpression
+from .nseq import DiscreteTimeDomainSequence, nseq
 from sympy import Sum, summation, limit, DiracDelta
 
 
 __all__ = ('nexpr', )
 
 class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
-    """Discrete time expression or symbol."""
+    """Discrete-time expression or symbol."""
 
     var = nsym
-
+    seqcls = DiscreteTimeDomainSequence
 
     def __init__(self, val, **assumptions):
 
@@ -127,17 +128,24 @@ class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
 
         return self.__class__(limit(self.expr, self.var, oo))
 
-    def DFT(self, N=None, evaluate=True):
-
-        from .kexpr import k
+    def DFT(self, N=None, evaluate=True, piecewise=False):
+        """Determine DFT.  
+        
+        `N` needs to be a positive integer symbol or a str specifying
+        the extent of the DFT.  By default `N` is defined as 'N'."""
+        
+        from .sym import symsymbol
 
         if N is None:
-            from .sym import symsymbol
-            
             N = symsymbol('N', integer=True, positive=True)
+        elif isinstance(N, str):
+            N = symsymbol(N, integer=True, positive=True)            
 
-        result = DFT(self.expr, nsym, ksym, N, evaluate=evaluate)
-        return self.change(result, domain='discrete fourier')
+        result = DFT(self.expr, nsym, ksym, N, evaluate=evaluate,
+                     piecewise=piecewise)
+        result = self.change(result, domain='discrete fourier')        
+        result = result.simplify_unit_impulse()
+        return result
     
     def delay(self,m):
         """Delay signal by m samples."""
@@ -167,13 +175,19 @@ class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
     def DTFT(self, var=None, images=oo, **assumptions):
         """Convert to Fourier domain using discrete time Fourier transform.
 
+        By default this returns the DTFT in terms of `f`.  Use
+        `.DTFT(w)` to get the angular frequency form, `.DTFT(F)` to
+        get the normalised frequency form, or `.DTFT(W)` to get the
+        normalised angular frequency form.
+
         Use `images = 0` to avoid the infinite number of spectral images.
+
         """
 
         from .extrafunctions import UnitStep        
         from .symbols import f, omega, Omega, F
         from .fexpr import fexpr
-        from .dtft import DTFT        
+        from .dtft import DTFT
         
         if var is None:
             var = f
@@ -183,10 +197,14 @@ class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
         dtft = DTFT(self.expr, self.var, fsym, images=images)
 
         result = fexpr(dtft)(var)
-        result = result.expand(diracdelta=True, wrt=var)
+        result = result.simplify_dirac_delta()
+        result = result.simplify_heaviside()
+        result = result.simplify_rect()        
+        
         # There is a bug in SymPy when simplifying Sum('X(n - m)', (m, -oo, oo))
         # result = result.simplify()
         result = result.cancel_terms()
+
         return result
 
     def norm_angular_fourier(self, **assumptions):
@@ -228,18 +246,20 @@ def nexpr(arg, **assumptions):
         return arg.__class__(arg, **assumptions)
     
     if isinstance(arg, str) and arg.startswith('{'):
-        return seq(arg)
+        return nseq(arg)
     
     from numpy import ndarray
     
     if isinstance(arg, (list, ndarray)):
-        return Sequence(arg, var=n).as_impulses()
+        return DiscreteTimeDomainSequence(arg, var=n).as_impulses()
 
     return DiscreteTimeDomainExpression(arg, **assumptions)
 
 
 from .expressionclasses import expressionclasses
 
-classs = expressionclasses.register('discrete time', DiscreteTimeDomainExpression)
+classes = expressionclasses.register('discrete time', DiscreteTimeDomainExpression)
+DiscreteTimeDomainVoltage = classes['voltage']
+DiscreteTimeDomainCurrent = classes['current']
 
 n = DiscreteTimeDomainExpression('n', integer=True)
