@@ -100,6 +100,17 @@ class AngularFourierDomainExpression(AngularFourierDomain, Expr):
         By default complex data is plotted as separate plots of magnitude (dB)
         and phase.
 
+        `kwargs` include:
+        `axes` - the plot axes to use otherwise a new figure is created
+        `xlabel` - the x-axis label
+        `ylabel` - the y-axis label
+        `ylabel2` - the second y-axis label if needed, say for mag and phase
+        `xscale` - the x-axis scaling, say for plotting as ms
+        `yscale` - the y-axis scaling, say for plotting mV
+        `norm` - use normalized frequency
+        `dbmin` - the smallest value to plot in dB (default -120)
+        in addition to those supported by the matplotlib plot command.
+
         The plot axes are returned.  This is a tuple for magnitude/phase or
         real/imaginary plots.
         """
@@ -107,6 +118,44 @@ class AngularFourierDomainExpression(AngularFourierDomain, Expr):
         from .plot import plot_angular_frequency
         return plot_angular_frequency(self, wvector, **kwargs)
 
+    def bode_plot(self, wvector=None, **kwargs):
+        """Plot frequency response for a frequency-domain phasor as a Bode
+        plot (but without the straight line approximations).  wvector
+        specifies the angular frequencies.  If it is a tuple (f1, f2), it sets
+        the frequency limits.   Since a logarithmic frequency scale is used,
+        f1 must be greater than 0.
+
+        For more info, see `plot`.
+        """
+        
+        from .plot import plot_angular_bode
+        return plot_angular_bode(self, wvector, **kwargs)
+
+    def nyquist_plot(self, wvector=None, log_frequency=True, **kwargs):
+        """Plot frequency response as a Nyquist plot (imaginary part versus
+        real part).  wvector specifies the angular frequencies.  If it is
+        a tuple (f1, f2), it sets the frequency limits as (f1, f2).
+
+        `npoints` set the number of plotted points.
+
+        The unit circle is shown by default.  This can be disabled with `unitcircle=False`.
+        """        
+
+        from .plot import plot_nyquist
+        return plot_nyquist(self, wvector, log_frequency=log_frequency, **kwargs)
+
+    def nichols_plot(self, wvector=None, log_frequency=True, **kwargs):
+        """Plot frequency response as a Nichols plot (dB versus phase).
+        wvector specifies the angular frequencies.  If it is a tuple
+        (f1, f2), it sets the frequency limits as (f1, f2).
+
+        `npoints` set the number of plotted points.
+
+        """        
+
+        from .plot import plot_nichols
+        return plot_nichols(self, wvector, log_frequency=log_frequency, **kwargs)                    
+    
         
 def omegaexpr(arg, **assumptions):
     """Create AngularFourierDomainExpression object.  If `arg` is omegasym return omega"""
