@@ -75,7 +75,7 @@ class PhasorExpression(Expr):
         # TODO, think this through...
         var = self.omega
         if hasattr(var, 'expr'):
-            var = var.expr
+            raise ValueError('FIXME, omega is Lcapy symbol')
 
         # Handle things like 2 * pi * f
         if isinstance(var, symExpr) and var.is_Mul:
@@ -96,11 +96,6 @@ class PhasorExpression(Expr):
         
         return self.time().angular_fourier()            
     
-    def laplace(self, **assumptions):
-        """Convert to Laplace domain representation."""
-
-        return self.time().laplace()
-
     def phasor(self, **assumptions):
         """Convert to phasor representation."""
 
@@ -142,9 +137,7 @@ class PhasorExpression(Expr):
         if not self.is_phasor_frequency_domain:
             raise ValueError('Not frequency domain phasor: use plot()')
 
-        result = self.subs(self.omega, 2 * pi * fsym)
-        result = self.change(result, domain='fourier')
-        
+        result = self.fourier()
         return plot_bode(result, fvector, **kwargs)
 
     def _mul_compatible(self, x):
@@ -172,6 +165,9 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
         elif 'omega' not in assumptions or assumptions['omega'] is None:
             assumptions['omega'] = omegasym
 
+        if hasattr(assumptions['omega'], 'expr'):
+            assumptions['omega'] = assumptions['omega'].expr
+            
         assumptions['ac'] = True
         super (PhasorExpression, self).__init__(val, **assumptions)
     
@@ -205,7 +201,7 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
             raise ValueError(
                 'Do not know how to convert %s to phasor.  Expecting an AC signal.' % expr)
         
-        if omega is not None and check.omega != omega.expr:
+        if omega is not None and check.omega != omega:
             raise ValueError('Expecting omega=%s, found omega=%s.' % (omega, check.omega))
 
         if check.omega == 0:
@@ -232,6 +228,11 @@ class PhasorTimeDomainExpression(PhasorTimeDomain, PhasorExpression):
             result = self.real.expr * cos(omega1 * t) - self.imag.expr * sin(omega1 * t)
 
         return TimeDomainExpression(result).as_quantity(self.quantity)
+
+    def laplace(self, **assumptions):
+        """Convert to Laplace domain representation."""
+
+        return self.time().laplace()
     
 
 class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
@@ -274,6 +275,8 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
 
         if omega is None:
             omega = omegasym
+        elif hasattr(omega, 'expr'):
+            omega = omega.expr
 
         if expr.is_voltage or expr.is_current:
             print('Should convert %s expression to time-domain first' % expr.quantity)
@@ -293,14 +296,22 @@ class PhasorFrequencyDomainExpression(PhasorFrequencyDomain, PhasorExpression):
     
     def time(self, **assumptions):
         """Convert to time domain representation."""
+
+        return self.laplace().time()
+
+    def laplace(self, **assumptions):
+        """Convert to Laplace domain representation."""
+
         from .sym import ssym        
         from .sexpr import LaplaceDomainExpression
 
+        ass = self.assumptions.copy()
+        assumptions = ass.merge(**assumptions)        
+        
         omega = self.omega
-        result = self.expr.replace(omega.expr, ssym / j)
-        result2 = LaplaceDomainExpression(result, **self.assumptions)
-        return self.change(result2.time(), domain='time')
-
+        result = self.expr.replace(omega, ssym / j)
+        return LaplaceDomainExpression(result, **assumptions).as_quantity(self.quantity)
+    
     def as_expr(self):
         return PhasorFrequencyDomainExpression(self)
 
