@@ -5,6 +5,7 @@ Copyright 2014--2021 Michael Hayes, UCECE
 """
 
 import numpy as np
+from .symbols import pi
 from .utils import separate_dirac_delta, factor_const
 from sympy import DiracDelta, solve
 
@@ -29,8 +30,27 @@ def make_axes(figsize=None, axes=None, **kwargs):
     return axes
 
 
+def parse_range(frange, zero=0.1, positive=False):
+
+    # Ensure that have floats.  This deals with SymPy symbols.
+    fmin = float(frange[0])
+    fmax = float(frange[1])
+
+    if fmax < fmin:
+        raise ValueError('Max value smaller than min value')
+    
+    if positive and fmin < 0:
+        raise ValueError('Min value not positive.')
+
+    if positive and fmin == 0:
+        fmin = zero
+
+    return fmin, fmax
+
+
 def plot_deltas(ax, t, deltas, var, plot_type='real', color='k'):
 
+    vals = []
     for delta in deltas:
         delta = delta.expand(diracdelta=True, wrt=var)
         const, expr = factor_const(delta, var)        
@@ -57,11 +77,32 @@ def plot_deltas(ax, t, deltas, var, plot_type='real', color='k'):
             raise ValueError('Unhandled plot type %s' % plot_type)
 
         if t0 >= min(t) and t0 <= max(t):
-            ax.arrow(t0, 0, 0, const, lw=1.5,  fc=color, ec=color,
-                     head_width=0.1, head_length=0.2, overhang=0.1,
-                     length_includes_head=True, clip_on=False)            
+            vals.append((t0, const))
 
+    vals = np.array(vals)
+
+    tmin, tmax = ax.get_xlim()        
+    T = tmax - tmin
+    ymin, ymax = ax.get_ylim()
+    yvalsmax = vals[:, 1].max()
+    
+    for t0, y in vals:
         
+        # TODO: determine best scaling
+        y1 = y / yvalsmax * ymax / 2
+        
+        st = T / 10
+        sy = ymax
+        
+        ax.arrow(t0, 0, 0, y1, fc=color, ec=color,
+                 width = 0.025 * st, head_width=0.1 * st,
+                 head_length=0.1 * sy, overhang=0,
+                 length_includes_head=True, clip_on=False)
+        
+        # TODO: nicely format the scale factor
+        ax.text(t0 + T / 100, y1 + ymax / 100, '%.*g' % (3, y))
+
+            
 def plot_pole_zero(obj, **kwargs):
 
     from matplotlib.pyplot import Circle, rcParams
@@ -167,7 +208,7 @@ def plot_pole_zero(obj, **kwargs):
 
 
 def plotit(ax, obj, f, V, plot_type=None, deltas=None, log_magnitude=False,
-           log_frequency=False, norm=False, **kwargs):
+           log_frequency=False, norm=False, dbmin=-120, **kwargs):
 
     plots = {(True, True) : ax.loglog,
              (True, False) : ax.semilogy,
@@ -190,7 +231,10 @@ def plotit(ax, obj, f, V, plot_type=None, deltas=None, log_magnitude=False,
         V = abs(V)
         part = 'magnitude'        
     elif plot_type == 'dB':
-        V = 20 * np.log10(abs(V))
+        Vabs = abs(V)
+        Vmin = 10**(dbmin / 20)
+        Vabs[Vabs < Vmin] = Vmin
+        V = 20 * np.log10(Vabs)
         part = 'magnitude'        
         units = 'dB'
     elif plot_type == 'radians':
@@ -261,6 +305,7 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
         log_magnitude = True 
         log_frequency = True
 
+    dbmin = kwargs.pop('dbmin', -120)        
     label = kwargs.pop('label', None)        
     nyticks = kwargs.pop('nyticks', None)
     color2 = kwargs.pop('color2', None)
@@ -276,10 +321,11 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
         f = (0, f)
     if isinstance(f, tuple):
         if log_frequency:
-            fmin = f[0] if f[0] > 0 else 1e-1            
-            f = np.geomspace(fmin, f[1], npoints)
+            fmin, fmax = parse_range(f, 1e-1, positive=True)
+            f = np.geomspace(fmin, fmax, npoints)
         else:
-            f = np.linspace(f[0], f[1], npoints)            
+            fmin, fmax = parse_range(f, 1e-1, positive=False)            
+            f = np.linspace(fmin, fmax, npoints)            
 
     # Objects can have a `part` attribute that is set by methods such
     # as real, imag, phase, magnitude.  If this is defined,
@@ -299,7 +345,9 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
         elif plot_type in ('dB', ):
             plot1_type = 'dB'
         elif plot_type in ('real', ):
-            plot1_type = 'real'            
+            plot1_type = 'real'
+        elif plot_type in ('abs', ):
+            plot1_type = 'abs'                        
 
     elif obj.part == '':
 
@@ -329,7 +377,9 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
         elif plot_type in ('phase', 'radians'):
             plot1_type = 'radians'
         elif plot_type in ('phase-degrees', 'degrees'):
-            plot1_type = 'degrees'            
+            plot1_type = 'degrees'
+        elif plot_type == 'abs':
+            plot1_type = 'abs'            
         elif plot_type == 'real':
             plot1_type = 'real'
         elif plot_type == 'imag':
@@ -340,7 +390,7 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
             types = ['dB-phase', 'dB-radians', 'dB-phase-degrees', 'dB-degrees',
                      'mag-phase', 'magnitude-phase', 'mag-phase-degrees','magnitude-phase-degrees',
                      'real-imag', 'mag', 'magnitude', 'phase', 'radians', 'phase-degrees',
-                     'degrees', 'real', 'imag', 'dB']
+                     'degrees', 'real', 'imag', 'dB', 'abs']
             
             raise ValueError('Unknown plot type: %s. Use: %s ' % (plot_type, ', '.join(types)))
 
@@ -359,7 +409,7 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
         label = plot1_type
     
     lines = plotit(ax, obj, f, V, plot1_type, deltas, log_frequency=log_frequency,
-                   log_magnitude=log_magnitude, norm=norm, label=label, **kwargs)
+                   log_magnitude=log_magnitude, norm=norm, label=label, dbmin=dbmin, **kwargs)
     
     if plot2_type is None:
         return ax
@@ -367,10 +417,12 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
     if color2 is None:
         color2 = lines[0].get_color()
 
-    kwargs.pop('color', None)
-    kwargs.pop('linestyle', None)
+    kwargs2 = kwargs.copy()
+    for key in ('color', 'linestyle', 'xlabel', 'xlabel2', 'ylabel', 'title', 'xscale', 'yscale'):
+        kwargs2.pop(key, None)
+    
     # Dummy plot to add label to legend.
-    ax.plot([], [], label=plot2_type, color=color2, linestyle=linestyle2, **kwargs)
+    ax.plot([], [], label=plot2_type, color=color2, linestyle=linestyle2, **kwargs2)
     
     ax2 = ax.twinx()
     kwargs['axes'] = ax2
@@ -385,7 +437,10 @@ def plot_frequency(obj, f, plot_type=None, **kwargs):
         ax2.set_ylim(-180, 180)
 
     if plot1_type == 'dB':
-        dB = 20 * np.log10(abs(V))
+        Vabs = abs(V)
+        Vmin = 10**(dbmin / 20)        
+        Vabs[Vabs < Vmin] = Vmin
+        dB = 20 * np.log10(Vabs)
         dBmin = min(dB)
         dBmax = max(dB)
 
@@ -420,6 +475,14 @@ def plot_bode(obj, f, **kwargs):
     return plot_frequency(obj, f, **kwargs)
 
 
+def plot_angular_bode(obj, f, **kwargs):
+
+    if 'log_frequency' not in kwargs:
+        kwargs['log_frequency'] = True
+
+    return plot_angular_frequency(obj, f, **kwargs)
+
+
 def plot_angular_frequency(obj, omega, plot_type=None, **kwargs):
 
     npoints = kwargs.pop('npoints', 400)
@@ -434,7 +497,8 @@ def plot_angular_frequency(obj, omega, plot_type=None, **kwargs):
     if isinstance(omega, (int, float)):
         omega = (0, omega)
     if isinstance(omega, tuple):
-        omega = np.linspace(omega[0], omega[1], npoints)
+        wmin, wmax = parse_range(omega, 1e-1, positive=False)        
+        omega = np.linspace(wmin, wmax, npoints)
 
     if norm and 'xlabel' not in kwargs:
         kwargs['xlabel'] = 'Normalized angular frequency'
@@ -454,7 +518,8 @@ def plot_time(obj, t, plot_type=None, **kwargs):
     if isinstance(t, (int, float)):
         t = (0, t)
     if isinstance(t, tuple):
-        t = np.linspace(t[0], t[1], npoints)
+        tmin, tmax = parse_range(t, 1e-1, positive=False)                
+        t = np.linspace(tmin, tmax, npoints)
 
     deltas = None
     if obj.has(DiracDelta):
@@ -466,11 +531,11 @@ def plot_time(obj, t, plot_type=None, **kwargs):
         
     if plot_type == None:
         plot_type = 'real'
-    if plot_type=='real':
+    if plot_type == 'real':
         v = v.real
-    elif plot_type=='imag':
+    elif plot_type == 'imag':
         v = v.imag
-    elif plot_type=='abs':
+    elif plot_type == 'abs':
         v = abs(v)
     else:
         raise ValueError('Invalid plot_type: must be real, imag, real-imag, abs')
@@ -560,11 +625,11 @@ def plot_sequence(obj, ni, plot_type=None, polar=False, **kwargs):
 
     if plot_type == None:
         plot_type = 'real'
-    if plot_type=='real':
+    if plot_type == 'real':
         v = v.real
-    elif plot_type=='imag':
+    elif plot_type == 'imag':
         v = v.imag
-    elif plot_type=='abs':
+    elif plot_type == 'abs':
         v = abs(v)
     else:
         raise ValueError('Invalid plot_type: must be real, imag, real-imag, abs')
@@ -620,20 +685,39 @@ def plot_phasor(obj, **kwargs):
     return ax
 
 
-def plot_nyquist(obj, f, **kwargs):
+def plot_nyquist(obj, f, norm=False, **kwargs):
 
     from matplotlib.pyplot import Circle, rcParams
 
-    npoints = kwargs.pop('npoints', 400)    
+    npoints = kwargs.pop('npoints', 400)
+    # Default to True to get better plots.
+    log_frequency = kwargs.pop('log_frequency', False)
+    unitcircle = kwargs.pop('unitcircle', True)
+
+    fn = None
 
     # FIXME, determine useful frequency range...
     if f is None:
-        f = (0, 100)
+        f = (-100, 100)
     if isinstance(f, (int, float)):
         f = (0, f)
     if isinstance(f, tuple):
-        fmin = f[0] if f[0] > 0 else 1e-4
-        f = np.geomspace(fmin, f[1], npoints)            
+        fmin, fmax = parse_range(f, 1e-1, positive=False)        
+        if log_frequency:
+            if fmin < 0:
+                frange = fmax - fmin
+                f = np.geomspace(frange / 1e4, fmax, npoints // 2)
+                f = np.hstack((0, f))
+                fn = -np.geomspace(frange / 1e4, abs(fmin), npoints // 2)
+                fn = np.hstack((0, fn))
+            elif fmin == 0:
+                f = np.geomspace(fmax / 1e4, fmax, npoints // 2)
+                f = np.hstack((0, f))                
+            else:
+                f = np.geomspace(fmin, fmax, npoints)
+        else:
+            fmin, fmax = parse_range(f, 1e-1, positive=False)            
+            f = np.linspace(fmin, fmax, npoints)                    
     
     if not obj.is_complex:
         raise ValueError('Data not complex')
@@ -643,17 +727,14 @@ def plot_nyquist(obj, f, **kwargs):
     ax = make_axes(figsize=kwargs.pop('figsize', None),
                    axes=kwargs.pop('axes', None))
 
-    unitcircle = kwargs.pop('unitcircle', True)
-    mirror = kwargs.pop('mirror', True)        
-    
     if unitcircle:
         ax.add_artist(Circle((0, 0), 1, color='blue', linestyle='--', fill=False))
 
     V = obj.evaluate(f)
     lines = ax.plot(V.real, V.imag)
 
-    if mirror:
-        V = obj.evaluate(-f)
+    if fn is not None:
+        V = obj.evaluate(fn)
         color = lines[0].get_color()
         ax.plot(V.real, V.imag, color=color)    
 
@@ -700,3 +781,68 @@ def plot_nyquist(obj, f, **kwargs):
     
     return ax
     
+
+def plot_nichols(obj, f, norm=False, **kwargs):
+
+    from matplotlib.pyplot import Circle, rcParams
+
+    npoints = kwargs.pop('npoints', 400)
+    # Default to True to get better plots.
+    log_frequency = kwargs.pop('log_frequency', False)
+    unitcircle = kwargs.pop('unitcircle', True)
+
+    fn = None
+
+    # FIXME, determine useful frequency range...
+    if f is None:
+        f = (-100, 100)
+    if isinstance(f, (int, float)):
+        f = (0, f)
+    if isinstance(f, tuple):
+        fmin, fmax = parse_range(f, 1e-1, positive=False)        
+        if log_frequency:
+            if fmin < 0:
+                frange = fmax - fmin
+                f = np.geomspace(frange / 1e4, fmax, npoints // 2)
+                f = np.hstack((0, f))
+                fn = -np.geomspace(frange / 1e4, abs(fmin), npoints // 2)
+                fn = np.hstack((0, fn))
+            elif fmin == 0:
+                f = np.geomspace(fmax / 1e4, fmax, npoints // 2)
+                f = np.hstack((0, f))                
+            else:
+                f = np.geomspace(fmin, fmax, npoints)
+        else:
+            fmin, fmax = parse_range(f, 1e-1, positive=False)            
+            f = np.linspace(fmin, fmax, npoints)                    
+    
+    if not obj.is_complex:
+        raise ValueError('Data not complex')
+    
+    obj = obj.doit()
+
+    ax = make_axes(figsize=kwargs.pop('figsize', None),
+                   axes=kwargs.pop('axes', None))
+
+    V = obj.evaluate(f)
+    lines = ax.plot(np.angle(V), 20 * np.log10(abs(V)))
+
+    if fn is not None:
+        V = obj.evaluate(fn)
+        color = lines[0].get_color()
+        ax.plot(np.angle(V), 20 * np.log10(abs(V)), color=color)
+
+    xlabel = kwargs.pop('xlabel', 'Phase (radians)')
+    ylabel = kwargs.pop('ylabel', 'dB')
+    title = kwargs.pop('title', None)
+
+    if xlabel is not None:
+        ax.set_xlabel(xlabel)
+    if ylabel is not None:        
+        ax.set_ylabel(ylabel)
+    if title is not None:
+        ax.set_title(title)        
+
+    ax.grid(True)
+    
+    return ax
