@@ -82,8 +82,11 @@ class Pole(object):
         return scale, offset, scale2, dexpr
 
     @property
+    def conj(self):
+        return self.conjugate()
+
     def conjugate(self):
-        return self._rewrite(conjugate=True)        
+        return self._rewrite(conjugate=True)            
         
     def _rewrite(self, conjugate=False):
 
@@ -374,6 +377,7 @@ class Ratfun(object):
         return poles
 
     def residue(self, pole, poles):
+        """Determine residue for given pole."""
 
         expr = self.expr
         var = self.var
@@ -424,7 +428,6 @@ class Ratfun(object):
         m2 = method2(numer, denom, var, pole)        
         return m2.cancel()
 
-
     @property
     def numerator_denominator(self):
         """Return numerator and denominator of rational function"""
@@ -650,7 +653,6 @@ class Ratfun(object):
         
         return result
         
-
     def residues(self, combine_conjugates=False, damping=None):
         """Return residues of partial fraction expansion.
 
@@ -788,8 +790,10 @@ class Ratfun(object):
                     expr2 = expr * (var - p) ** o                
                     for n in range(1, o + 1):
                         m = o - n
-                        r = sym.limit(
-                            sym.diff(expr2, var, m), var, p) / sym.factorial(m)
+
+                        dexpr = sym.diff(expr2, var, m)
+                        r = sym.limit(dexpr, var, p) / sym.factorial(m)
+                        
                         rc = r.conjugate()
                         r = sym.simplify(r * (var - pc) ** n + rc * (var - p) ** n)
                         R.append(r)
@@ -811,8 +815,9 @@ class Ratfun(object):
                     expr2 = expr * (var - p) ** o
                     for n in range(1, o + 1):
                         m = o - n
-                        r = sym.limit(
-                            sym.diff(expr2, var, m), var, p) / sym.factorial(m)
+
+                        dexpr = sym.diff(expr2, var, m).simplify()
+                        r = sym.limit(dexpr, var, p) / sym.factorial(m)
 
                         R.append(r)
                         D.append(D2 ** n)                        
