@@ -1,4 +1,4 @@
-"""This modules provides the SequenceExpression class to provide
+"""This module provides the SequenceExpression class to provide
 common methods for the discrete-time and discrete-frequency
 expressions.
 
@@ -8,8 +8,8 @@ Copyright 2020--2021 Michael Hayes, UCECE
 
 from .dexpr import DiscreteExpression
 from .sequence import Sequence
-from .functions import Heaviside, DiracDelta
-from .extrafunctions import UnitStep, UnitImpulse
+from .functions import Heaviside, DiracDelta, rect, sign
+from .extrafunctions import UnitStep, UnitImpulse, dtrect, dtsign
 from numpy import arange
 
 
@@ -20,11 +20,16 @@ class SequenceExpression(DiscreteExpression):
 
         super(SequenceExpression, self).__init__(val, **assumptions)
 
-        if self.has(Heaviside):
-            self.expr = self.replace(Heaviside, UnitStep).expr
-        if self.has(DiracDelta):
-            self.expr = self.replace(DiracDelta, UnitImpulse).expr
+        mapping = {Heaviside: UnitStep,
+                   DiracDelta: UnitImpulse,
+                   rect: dtrect,
+                   sign: dtsign}
 
+        # Use discrete-time function variants, see also functions.py
+        for old, new in mapping.items():
+            if self.has(old):
+                self.expr = self.replace(old, new).expr                
+                
     def first_index(self, ni=None):
 
         if ni is None:
@@ -94,6 +99,6 @@ class SequenceExpression(DiscreteExpression):
             
         v = self(ni)
         
-        return Sequence(v, ni, evaluate=evaluate, var=self.var,
-                        start_trunc=start_trunc, end_trunc=end_trunc)
+        return self.seqcls(v, ni, evaluate=evaluate,
+                           start_trunc=start_trunc, end_trunc=end_trunc)
        
