@@ -4,16 +4,50 @@ Copyright 2020-2021 Michael Hayes, UCECE
 
 """
 
-from .expr import ExprList, expr
+from .expr import ExprList, ExprDomain, expr
 from .utils import isiterable
+from .assumptions import Assumptions
 from numpy import array, allclose, arange
 
 # Perhaps subclass numpy ndarray?  But then could not have symbolic
-# elements in the sequence.  Perhaps have flavours for n-domain and
-# k-domain sequences?
+# elements in the sequence.  
 
-class Sequence(ExprList):
+def parse_seq_str(s):
 
+    if s.startswith('{'):
+        if not s.endswith('}'):
+            raise ValueError('Mismatched braces for %s' % s)
+        s = s[1:-1]
+    
+    parts = s.split(',')
+    N = len(parts)
+
+    vals = []
+    m0 = None
+    for m, item in enumerate(parts):
+        item = item.strip()
+        if item.startswith('_'):
+            if m0 is not None:
+                raise ValueError('Cannot have multiple zero index indicators')
+            m0 = m
+            item = item[1:]
+
+        val = expr(item)
+        vals.append(val)
+
+    if m0 is None:
+        m0 = 0
+        
+    ni = range(-m0, N - m0)
+    return vals, ni
+
+
+class Sequence(ExprList, ExprDomain):
+
+    var = None
+    is_sequence = True
+    quantity = 'undefined'
+    
     def __init__(self, seq, ni=None, origin=None, evaluate=False, var=None,
                  start_trunc=False, end_trunc=False):
         """Sequences can be created from an tuple, list, or ndarray.
@@ -37,7 +71,7 @@ class Sequence(ExprList):
         [-1, 0, 1, 2]
 
         Sequences can be converted into discrete-time, discrete-frequency,
-        z-domain expressions using call notation, for example::
+        z-domain sequences using call notation, for example::
         
         >>> a(z)
 
@@ -49,6 +83,13 @@ class Sequence(ExprList):
         the sequence has been truncated.
 
         """
+
+        if isinstance(seq, str):
+            seq, ni = parse_seq_str(seq)
+
+        if not isiterable(seq):
+            seq = (seq, )        
+        
         super (Sequence, self).__init__(seq, evaluate)
 
         if ni is not None and origin is not None:
@@ -63,22 +104,65 @@ class Sequence(ExprList):
         # Perhaps enforce contiguous sequences and just store the origin.
         # This will simplify sequence comparison.
         self.n = list(ni)
-        self.var = var
 
         # Determine if sequence truncated at start, end, or both.
         # Perhaps have separate classes for truncated sequences?
         self.start_trunc = start_trunc
         self.end_trunc = end_trunc
+        # For symmetry with Expr
+        self.assumptions = Assumptions()        
 
     @property
     def vals(self):
         """Return the SymPy values as a list."""
         return list(self)
 
+    @property
+    def _pexpr(self):
+        """Return expression for printing."""
+        return self
+
     def __eq__(self, x):
 
+        self._check_compatible(x)        
         return self.vals == x.vals and self.n == x.n
 
+    def _check_compatible(self, x):
+        
+        if not isinstance(x, Sequence):
+            raise TypeError('Can only add a sequence to a sequence')
+        if x.quantity != 'undefined' and self.quantity != 'undefined' and x.quantity != self.quantity:
+            raise TypeError('Sequences have different quantities: %s and %s' % (self.quantity, x.quantity))
+
+        if self.domain != x.domain:
+            raise TypeError('Sequences have different domains: %s and %s' % (self.domain, x.domain))            
+        
+    def __abs__(self):
+        """Absolute value of each element."""
+
+        raise ValueError('abs operator not supported for %s: use .as_array()' % self.__class__.__name__)
+
+    def __neg__(self):
+        """Negation of each element."""
+
+        raise ValueError('- operator not supported for %s: use .as_array()' % self.__class__.__name__)
+
+    def __add__(self, x):
+        """Concatenate with sequence x."""
+
+        self._check_compatible(x)
+        if self.quantity == 'undefined':
+            cls = x.__class__
+        else:
+            cls = self.__class__
+        
+        return cls(super(Sequence, self).__add__(x))
+
+    def __mul__(self, x):
+        """Replicate x times."""
+
+        return self.__class__(super(Sequence, self).__mul__(x))    
+    
     def __lshift__(self, m):
 
         return self.delay(-m)
@@ -143,11 +227,11 @@ class Sequence(ExprList):
 
         m2 = len(vals) - 1
         if vals[m2] != 0:
-            return Sequence(vals[m1:], self.n[m1:])
+            return self.__class__(vals[m1:], self.n[m1:])
         
         while vals[m2] == 0:
             m2 -= 1        
-        return Sequence(vals[m1:m2 + 1], self.n[m1:m2 + 1])
+        return self.__class__(vals[m1:m2 + 1], self.n[m1:m2 + 1])
 
     def zeropad(self, M):
         """Add M zeros to end of sequence:
@@ -164,32 +248,8 @@ class Sequence(ExprList):
             vals.append(zero)
 
         ni = self.n + list(range(self.n[-1] + 1, len(vals)))
-        return self.__class__(vals, ni, var=self.var)        
+        return self.__class__(vals, ni)        
     
-    def latex(self):
-
-        a = self.zeroextend()
-
-        items = []
-        if self.start_trunc:
-            items.append('\\ldots')
-            
-        for v1, n1 in zip(a, a.n):
-            try:
-                s = v1.latex()
-            except:
-                s = str(v1)
-            
-            if n1 == 0:
-                s = r'\underline{%s}' % v1
-            items.append(s)
-
-        if self.end_trunc:
-            items.append('\\ldots')
-            
-        return r'\left\{%s\right\}' % ', '.join(items)
-
-
     def __str__(self):
 
         a = self.zeroextend()
@@ -236,6 +296,9 @@ class Sequence(ExprList):
     def expr(self):
         """Convert sequence to an Lcapy expression."""
 
+        if self.var is None:
+            raise ValueError('var not specified')            
+        
         return self.as_impulses(self.var)
         
     def as_impulses(self, var=None):
@@ -254,7 +317,7 @@ class Sequence(ExprList):
         # This can reorder terms
         result = var * 0
         for v1, n1 in zip(self, self.n):        
-            result += v1 * unitimpulse(var - n1)
+            result += v1.as_constant() * unitimpulse(var - n1)
 
         # but so does the unevaluated Add...
         # items = []
@@ -272,7 +335,7 @@ class Sequence(ExprList):
         complex.  Zeroes are returned for indices outside the sequence
         extent.
 
-        If arg is iterable, a NumPy array is returned.
+        If `arg` is iterable, a NumPy array is returned.
 
         """
         
@@ -350,26 +413,25 @@ class Sequence(ExprList):
         """Convert sequence to n-domain or k-domain expression.
         For example, seq((1, 2, 3))(n)"""
 
-        from .nexpr import n
-        from .kexpr import k
-        from .zexpr import z
+        from .symbols import n, k, z
+        from .dsym import nsym, ksym, zsym
 
         if id(arg) == id(n) or arg == n:
-            if self.var == n:
+            if self.var == nsym:
                 return self.copy()
-            elif self.var == k:
+            elif self.var == ksym:
                 return self.IDFT()
             return self.IZT()            
         if id(arg) == id(k) or arg == k:
-            if self.var == k:
+            if self.var == ksym:
                 return self.copy()            
-            elif self.var == z:
+            elif self.var == zsym:
                 return self.IZT().DFT()
             return self.DFT()
         if id(arg) == id(z) or arg == z:
-            if self.var == z:
+            if self.var == zsym:
                 return self.copy()            
-            elif self.var == k:
+            elif self.var == ksym:
                 return self.IDFT().ZT()
             return self.ZT()
 
@@ -389,12 +451,12 @@ class Sequence(ExprList):
 
     def copy(self):
         return self.__class__(super(Sequence, self).copy(),
-                               self.n, var=self.var)
+                               self.n)
         
     def lfilter(self, b=None, a=None):
         """Implement digital filter specified by a transfer function.  The
         transfer function is described by a vector `b` of coefficients
-        for the numerator and a `a` vector of coefficients for the
+        for the numerator and an `a` vector of coefficients for the
         denominator. 
         
         If you would like the response with initial conditions see
@@ -429,7 +491,7 @@ class Sequence(ExprList):
                     pass
             y[-1] = yn
                 
-        return self.__class__(y, self.n, var=self.var)
+        return self.__class__(y, self.n)
     
     def convolve(self, h, mode='full'):
         """Convolve with h."""
@@ -460,7 +522,7 @@ class Sequence(ExprList):
         origin = self.origin - m
         ni = list(arange(-origin, len(self) - origin))
         
-        return self.__class__(self.vals, ni, var=self.var)                
+        return self.__class__(self.vals, ni)                
 
     def zeroextend(self):
         """Extend sequence by adding zeros so that the origin
@@ -475,91 +537,6 @@ class Sequence(ExprList):
             vals = vals + [0] * -ni[-1]
             ni = range(ni[0], 1)            
 
-        return self.__class__(vals, ni, var=self.var,
+        return self.__class__(vals, ni,
                               start_trunc=self.start_trunc,
                               end_trunc=self.end_trunc)
-
-    def DFT(self):
-        """Calculate DFT and return as sequence."""
-
-        from sympy import exp
-        from .sym import j, pi
-        from .nexpr import n
-        from .kexpr import k
-
-        if self.var != n:
-            print('Warning, you should use IDFT since in discrete-frequency domain')
-        
-        results = []
-        vals = self.vals
-        N = len(vals)
-        for ki in range(N):
-            result = 0
-            for ni in range(N):            
-               result += vals[ni] * exp(-2 * j * pi * self.n[ni] * ki / N)
-            results.append(result)
-
-        return self.__class__(results, var=k)
-
-    def IDFT(self):
-        """Calculate IDFT and return as sequence."""
-
-        from sympy import exp
-        from .sym import j, pi
-        from .nexpr import n
-        from .kexpr import k
-
-        if self.var != k:
-            print('Warning, you should use IDFT since in discrete-time domain')
-        
-        results = []
-        vals = self.vals
-        N = len(vals)
-        for ni in range(N):            
-            result = 0
-            for ki in range(N):
-               result += vals[ki] * exp(2 * j * pi * ni * self.n[ki] / N)
-               
-            results.append(result / N)
-
-        return self.__class__(results, var=n)    
-
-    def ZT(self):
-        """Calculate z-transform and return as sequence."""
-
-        from .kexpr import k
-        from .zexpr import z
-
-        if self.var == z:
-            print('Warning, you should use IZT since in z-domain')
-        elif self.var == k:
-            return self.IDFT().ZT()
-        
-        results = []
-        vals = self.vals
-        N = len(vals)
-        for ni in range(N):
-            results.append(vals[ni] * z**(-ni))
-
-        return self.__class__(results, var=z)        
-
-    def IZT(self):
-        """Calculate inverse z-transform and return as sequence."""
-
-        from .kexpr import k
-        from .nexpr import n        
-        from .zexpr import z
-
-        if self.var == n:
-            print('Warning, you should use ZT since in discrete-time domain')
-        elif self.var == k:
-            return self.IDFT().IZT()
-        
-        results = []
-        vals = self.vals
-        N = len(vals)
-        for ni in range(N):
-            results.append(vals[ni] * z**ni)
-
-        return self.__class__(results, var=n)        
-    
