@@ -18,7 +18,9 @@ from sympy.core.function import AppliedUndef
 import sympy as sym
 import re
 from .state import state
-from .simplify import simplify_dirac_delta, simplify_heaviside
+from .simplify import simplify_dirac_delta, simplify_heaviside, simplify_rect
+from .simplify import simplify_unit_impulse
+from .extrafunctions import UnitImpulse, UnitStep, rect, dtrect
 
 __all__ = ('symsymbol', 'sympify', 'simplify', 'symbol_delete')
 
@@ -145,7 +147,7 @@ def parse(string, symbols=None, evaluate=True, local_dict=None,
                     result.append((NAME, name))
                     continue
 
-                # Automatically add Symbol                
+                # Automatically add Symbol
                 result.extend([(NAME, 'Symbol'),
                                (OP, '('), (NAME, repr(name))])
                 for assumption, val in assumptions.items():
@@ -177,7 +179,8 @@ def parse(string, symbols=None, evaluate=True, local_dict=None,
     return s
 
 
-def sympify1(arg, symbols=None, evaluate=True, override=False, **assumptions):
+def sympify1(arg, symbols=None, evaluate=True, override=False, rational=True,
+             **assumptions):
     """Create a SymPy expression.
 
     The purpose of this function is to head SymPy off at the pass and
@@ -192,13 +195,21 @@ def sympify1(arg, symbols=None, evaluate=True, override=False, **assumptions):
     if symbols is None:
         symbols = {}
 
-    if isinstance(arg, (Symbol, Expr)):
+    if isinstance(arg, Expr):
+        if not arg.has(sym.Float):
+            return arg
+        # This is needed to catch 0.1 + sym.I        
+        arg = arg.replace(lambda expr: expr.is_Float,
+                          lambda expr: sym.sympify(str(expr), rational=rational))
+        return arg
+        
+    if isinstance(arg, Symbol):
         return arg
 
     # Why doesn't SymPy do this?
     if isinstance(arg, complex):
-        re = sym.sympify(str(arg.real), rational=True, evaluate=evaluate)
-        im = sym.sympify(str(arg.imag), rational=True, evaluate=evaluate)
+        re = sym.sympify(str(arg.real), rational=rational, evaluate=evaluate)
+        im = sym.sympify(str(arg.imag), rational=rational, evaluate=evaluate)
         if im == 1.0:
             arg = re + sym.I
         else:
@@ -208,7 +219,7 @@ def sympify1(arg, symbols=None, evaluate=True, override=False, **assumptions):
     if isinstance(arg, float):
         # Note, need to convert to string to achieve a rational
         # representation.
-        return sym.sympify(str(arg), rational=True, evaluate=evaluate)
+        return sym.sympify(str(arg), rational=rational, evaluate=evaluate)
         
     if isinstance(arg, str):
         # Quickly handle the simple case.  
@@ -225,11 +236,11 @@ def sympify1(arg, symbols=None, evaluate=True, override=False, **assumptions):
         return parse(arg, symbols, evaluate=evaluate,
                      local_dict=symbols, global_dict=gdict, **assumptions)
 
-    return sym.sympify(arg, rational=True, locals=symbols, 
+    return sym.sympify(arg, rational=rational, locals=symbols, 
                        evaluate=evaluate)
 
 
-def sympify(expr, evaluate=True, override=False, **assumptions):
+def sympify(expr, evaluate=True, override=False, rational=True, **assumptions):
     """Create a SymPy expression.
 
     By default, symbols are assumed to be positive if no assumptions
@@ -254,36 +265,71 @@ def sympify(expr, evaluate=True, override=False, **assumptions):
             assumptions.pop('positive')
         
     return sympify1(expr, state.context.symbols, evaluate, override,
-                    **assumptions)
+                    rational, **assumptions)
 
 
-def symsymbol(name, **assumptions):
+def symsymbol1(name, override=True, force=False, **assumptions):
+
+    if override:
+        if name in state.context.domain_symbols:
+            if not force:
+                raise ValueError('Cannot override domain symbol %s without force=True' % name)
+            symbol_delete(name)
+
+        elif name in state.context.user_symbols:
+            symbol_delete(name)
+    
+    return sympify(name, override=override, **assumptions)
+
+
+def symsymbol(name, force=False, **assumptions):
     """Create a SymPy symbol.
 
+    This function allows symbol assumptions to be defined,
+    e.g., real=True, integer=True
+
     By default, symbols are assumed to be positive unless real is
     defined.
 
     """
-    return sympify(name, override=True, **assumptions)
+
+    usym = symsymbol1(name, **assumptions)
+    state.global_context.user_symbols[name] = usym
+    return usym
 
 
-def symsimplify(expr):
+def domainsymbol(name, **assumptions):
+    """Create a SymPy symbol and register as a domain symbol
+    that should not be overwritten."""
+    
+    dsym = symsymbol1(name, **assumptions)
+    state.global_context.domain_symbols[name] = dsym
+    return dsym
+
+
+def symsimplify(expr, var=None, **kwargs):
     """Simplify a SymPy expression.  This is a hack to work around
     problems with SymPy's simplify API."""
 
     # Handle Matrix types
     if hasattr(expr, 'applyfunc'):
-        return expr.applyfunc(lambda x: symsimplify(x))
+        return expr.applyfunc(lambda x: symsimplify(x, **kwargs))
 
     if expr.has(sym.DiracDelta):
         expr = simplify_dirac_delta(expr)
-    if expr.has(sym.Heaviside):
-        expr = simplify_heaviside(expr)
+    if expr.has(UnitImpulse):
+        expr = simplify_unit_impulse(expr)                
+    if expr.has(sym.Heaviside, UnitStep):
+        expr = simplify_heaviside(expr, var)
+    if expr.has(rect, dtrect):
+        expr = simplify_rect(expr, var)        
 
-    # This gets expanded into piecewise...
+    # This+ gets expanded into piecewise...
     if expr.has(sym.sign):
         # Could replace sign with dummy function, simplify, and then restore...
-        # Should replace 1 + sign(t) with 2 * Heaviside(t)
+        # Could replace 1 + sign(t) with 2 * Heaviside(t) but this depends
+        # on the definition of sign(t).  SymPy and NumPy define sign(0) = 0.
+        # This implies Heaviside(0) = 0.5.
         return expr
     
     try:
@@ -292,17 +338,17 @@ def symsimplify(expr):
     except:
         pass
 
-    expr = sym.simplify(expr)
+    expr = sym.simplify(expr, **kwargs)
 
     return expr
 
 
-def simplify(expr):
+def simplify(expr, **kwargs):
     """Simplify an Lcapy expression.  This is not straightforward, see
     sympy.simplify."""
 
     try:
-        return expr.simplify()
+        return expr.simplify(**kwargs)
     except:
         pass
 
@@ -310,7 +356,7 @@ def simplify(expr):
     if isinstance(expr, LExpr):
         expr = expr.expr
 
-    return symsimplify(expr)
+    return symsimplify(expr, **kwargs)
 
 
 def is_sympy(expr):
@@ -367,7 +413,7 @@ def symbol_map(name):
     if name in state.context.symbols:
         new = state.context.symbols[name]
     elif name in state.global_context.symbols:
-        new = state.global_context.symbols[name]            
+        new = state.global_context.symbols[name]
     else:
         # Perhaps have symbol defined using sympy?
         pass
@@ -375,15 +421,15 @@ def symbol_map(name):
 
 
 # The following are all SymPy symbols.
-ssym = symsymbol('s', complex=True)
-tsym = symsymbol('t', real=True)
-fsym = symsymbol('f', real=True)
-omegasym = symsymbol('omega', real=True)
+ssym = domainsymbol('s', complex=True)
+tsym = domainsymbol('t', real=True)
+fsym = domainsymbol('f', real=True)
+omegasym = domainsymbol('omega', real=True)
 omega0sym = symsymbol('omega_0', real=True)
 tausym = symsymbol('tau', real=True)
 nusym = symsymbol('nu', real=True)
-Omegasym = symsymbol('Omega', real=True)
-Fsym = symsymbol('F', real=True)
+Omegasym = domainsymbol('Omega', real=True)
+Fsym = domainsymbol('F', real=True)
 
 pi = sym.pi
 j = sym.I
@@ -391,6 +437,9 @@ oo = sym.oo
 inf = sym.oo
 one = sym.S.One
 
+# This is required for expr('I') to work
+state.context.symbols['I'] = sym.I
+
 try:
     from sympy.core.function import AppliedUndef
 except:
