@@ -10,6 +10,11 @@ from .fexpr import f
 from .texpr import t
 from .sexpr import s
 from .omegaexpr import omega, omega0
+from .normomegaexpr import Omega
+from .normfexpr import F
+from .nexpr import n
+from .kexpr import k
+from .zexpr import z
 
 # Import common SymPy symbols.
 from .sym import pi, j, oo, inf, one
@@ -24,3 +29,8 @@ jw0 = jomega0
 w = omega
 # This represents a specific angular frequency and is assumed to be positive
 w0 = omega0
+
+# Omega = omega * dt
+
+W = Omega
+
