@@ -37,6 +37,9 @@ class LcapyTester(unittest.TestCase):
 
         a = atan2(1, omega)
         self.assertEqual(type(a), AngularFourierDomainExpression, "atan2")
+
+        self.assertEqual(sign(-n).evaluate(0), 1, "sign(-n)")
+        self.assertEqual(sign(-n).evaluate(1), -1, "sign(-n)")        
         
     def test_heaviside(self):
 
@@ -56,8 +59,6 @@ class LcapyTester(unittest.TestCase):
                          delta(t - 1),
                          "rect(t / 4) * delta(t - 1)")
         
-
-        
     def test_sinc(self):
 
         a = sinc(n).evaluate(2)
