@@ -646,6 +646,7 @@ class AMatrix(TwoPortMatrix):
 
     @classmethod
     def transformer(cls, alpha):
+        """The voltage gain alpha = 1 / a, where a is the turns ratio."""
 
         alpha = ConstantDomainExpression(alpha)
 
@@ -894,6 +895,7 @@ class BMatrix(TwoPortMatrix):
 
     @classmethod
     def transformer(cls, alpha):
+        """The voltage gain alpha = 1 / a, where a is the turns ratio."""
 
         alpha = ConstantDomainExpression(alpha)
 
@@ -1783,6 +1785,21 @@ class TwoPort(Network, TwoPortMixin):
             pass
         return self
 
+    def __add__(self, OP):
+        """Series combination"""
+
+        return self.series(OP)
+
+    def __or__(self, OP):
+        """Parallel combination"""
+
+        return self.parallel(OP)
+
+    def __mul__(self, OP):
+        """Chained combination"""
+
+        return self.chain(OP)    
+    
 
 class TwoPortBModel(TwoPort):
 
@@ -2403,7 +2420,9 @@ class Shunt(TwoPortBModel):
 
 class IdealTransformer(TwoPortBModel):
 
-    """Ideal transformer voltage gain alpha, current gain 1 / alpha"""
+    """Ideal transformer voltage gain alpha, current gain 1 / alpha.
+    Note, alpha = 1 / a where a is the turns ratio defined as the
+    number of primary turns to the number of secondary turns, a = N_2 / N_1."""
 
     def __init__(self, alpha=1):
 
@@ -2464,7 +2483,7 @@ class IdealVoltageAmplifier(VoltageAmplifier):
 
         Av = LaplaceDomainExpression(Av)
         super(IdealVoltageAmplifier, self).__init__(
-            BMatrix.voltage_differentiator(Av))
+            BMatrix.voltage_amplifier(Av))
         self.args = (Av, )
 
 
