@@ -1,3 +1,8 @@
+"""This module provides common utility functions.
+
+Copyright 2021 Michael Hayes, UCECE
+"""
+
 import sympy as sym
 
 def factor_const(expr, var):
@@ -120,6 +125,17 @@ def isiterable(arg):
     return hasattr(arg, '__iter__')
 
 
+def factor_expr(expr, factor):
+    """Extract factor from expression or None if expression does
+    not have factor."""
+
+    factors = expr.as_ordered_factors()
+    if factor not in factors:
+        return None
+
+    return expr / factor
+
+
 def separate_dirac_delta(expr):
 
     terms = expr.as_ordered_terms()
@@ -135,12 +151,53 @@ def separate_dirac_delta(expr):
     return rest, deltas
 
 
+def split_dirac_delta(expr):
+    """Return expression as a list of terms.
+    The first term has no DiracDeltas, the second term collates
+    the DiracDeltas, the third term collates derivatives of DiracDeltas, etc.
+
+    For example, u(t) + DiractDelta(t, 1) returns [u(t), 0, DiracDelta(t, 1)]
+    """
+
+    terms = expr.as_ordered_terms()
+    parts = {}
+    rest = 0
+
+    # FIXME, DiracDelta needs to be a factor
+    
+    for term in terms:
+        if term.has(sym.DiracDelta):
+            if len(term.args) == 1:
+                if 1 not in parts:
+                    parts[1] = 0
+                parts[1] += term
+            else:
+                idx = term.args[1] + 1
+                if idx not in parts:
+                    parts[idx] = 0
+                parts[idx] += term
+        else:
+            parts[0] = term
+
+    maxkey = max(parts.keys())
+    result = []
+    for key in range(maxkey + 1):
+        if key in parts:
+            result.append(parts[key])
+        else:
+            result.append(0)
+            
+    return result
+
+
 def remove_images(expr, var, dt, m1=0, m2=0):
 
     if m2 == 0 and isinstance(m1, tuple) and len(m1) == 2:
         # Perhaps should warn that this might be deprecated?
         m1, m2 = m1
-    
+
+    remove_all =  m1 == 0 and m2 == 0
+        
     const, expr1 = factor_const(expr, var)
 
     result = sym.S.Zero
@@ -153,13 +210,33 @@ def remove_images(expr, var, dt, m1=0, m2=0):
         
     if not isinstance(expr1, sym.Sum):
         return expr
-    sumsym = expr1.args[1].args[0]
-    foo = var - sumsym / dt
-    if not expr1.args[0].has(foo):
-        return expr    
 
-    if m1 == 0 and m2 == 0:
-        return const * expr1.args[0].replace(foo, var)
+    sumsym = expr1.args[1].args[0]    
+
+    def query(expr):
+
+        return expr.is_Add and expr.has(var) and expr.has(sumsym)
+
+    def value(expr):
+        if not expr.is_Add:
+            return expr
+
+        if not expr.is_polynomial(var) and not expr.as_poly(var).is_linear:
+            return expr        
+        expr = expr.expand()
+        a = expr.coeff(var, 1)
+        b = expr.coeff(var, 0)
+
+        if a == 0:
+            return expr
+        if b / a != -sumsym / dt:
+            return expr
+        return a * var
+    
+    expr1 = expr1.replace(query, value)    
+
+    if remove_all:
+        return const * expr1.args[0]
 
     return const * sym.Sum(expr1.args[0], (sumsym, m1, m2))
 
