@@ -11,9 +11,10 @@ from .sym import j, pi, fsym, omegasym
 from .dsym import nsym, ksym, zsym, dt
 from .vector import Vector
 from .ratfun import _zp2tf, Ratfun
-from .dexpr import DiscreteExpression
-from .expr import symbol, expr, ExprDict
+from .expr import symbol, expr, ExprDict, ExprList
 from .diffeq import DifferenceEquation
+from .seqexpr import SequenceExpression
+from .zseq import ZDomainSequence
 from .functions import sqrt, exp
 import numpy as np
 from sympy import Eq, div, limit, oo, Sum
@@ -21,11 +22,11 @@ from sympy import Eq, div, limit, oo, Sum
 
 __all__ = ('zexpr', )
 
-class ZDomainExpression(ZDomain, DiscreteExpression):
+class ZDomainExpression(ZDomain, SequenceExpression):
     """z-domain expression or symbol."""
 
     var = zsym
-
+    seqcls = ZDomainSequence
 
     def __init__(self, val, **assumptions):
 
@@ -162,6 +163,26 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
 
         return y
 
+    def state_space(self, form='CCF'):
+        """Create state-space representation from transfer function.  Note,
+        state-space representations are not unique and are determined
+        by the `form` argument.  Currently this can be 'CCF' for the
+        controllable canonical form, 'OCF' for the observable
+        canonical form, or 'DCF' for the diagonal canonical form."""
+
+        from .dtstatespace import DTStateSpace
+        
+        a = self.a
+        b = self.b
+
+        return DTStateSpace.from_transfer_function_coeffs(b, a, form)
+
+    @property
+    def ss(self):
+        """Return state-space representation using controllable canonical form.
+        For other forms, use `state_space()`."""
+
+        return self.state_space()
     def _decompose(self):
 
         N, D, delay = Ratfun(self, z).as_ratfun_delay()                
@@ -192,6 +213,57 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
         from .plot import plot_pole_zero
         return plot_pole_zero(self, **kwargs)
 
+    def bode_plot(self, fvector=None, **kwargs):
+        """Plot frequency response for a frequency-domain phasor as a Bode
+        plot (but without the straight line approximations), assumong
+        `dt=1`.  fvector specifies the frequencies.  If it is a tuple
+        (f1, f2), it sets the frequency limits.  Since a logarithmic
+        frequency scale is used, f1 must be greater than 0.
+
+        This method makes the assumption that the expression is causal.
+
+        """
+        from .discretetime import dt        
+
+        return self.DTFT(causal=True).subs(dt, 1).bode_plot(fvector, **kwargs)
+
+    def nyquist_plot(self, fvector=None, log_frequency=False, **kwargs):
+        """Plot frequency response for a frequency-domain phasor as a Nyquist
+        plot assuming `dt=1`.  fvector specifies the frequencies.  If it is a tuple
+        (f1, f2), it sets the frequency limits.
+
+        The unit circle is shown by default.  This can be disabled with `unitcircle=False`.
+
+        `npoints` set the number of plotted points.
+
+        This method makes the assumption that the expression is causal.
+        """        
+        from .discretetime import dt
+
+        if fvector is None:
+            fvector = (-0.5, 0.5)
+        return self.DTFT(causal=True).subs(dt, 1).nyquist_plot(fvector,
+                                                               log_frequency=log_frequency,
+                                                               **kwargs)
+
+    def nichols_plot(self, fvector=None, log_frequency=False, **kwargs):
+        """Plot frequency response for a frequency-domain phasor as a Nichols
+        plot assuming `dt=1`.  fvector specifies the frequencies.  If
+        it is a tuple (f1, f2), it sets the frequency limits.
+
+        `npoints` set the number of plotted points.
+
+        This method makes the assumption that the expression is causal.
+
+        """        
+        from .discretetime import dt
+
+        if fvector is None:
+            fvector = (-0.5, 0.5)
+        return self.DTFT(causal=True).subs(dt, 1).nichols_plot(fvector,
+                                                               log_frequency=log_frequency,
+                                                               **kwargs)    
+
     def inverse_bilinear_transform(self):
 
         from .symbols import s
@@ -201,11 +273,19 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
         
         return self.subs((1 + s * dt / 2) / (1 - s * dt / 2))
 
+    def DFT(self, N=None, evaluate=True, **assumptions):
+        """Determine DFT.  
+        
+        `N` needs to be a positive integer symbol or a str specifying
+        the extent of the DFT.  By default `N` is defined as 'N'."""
+
+        result = self.IZT(**assumptions).DFT(N=N)
+        return result
+
     def discrete_time_fourier_transform(self, var=None, images=oo,
                                         **assumptions):
         """Convert to Fourier domain using discrete time Fourier transform."""
         return self.DTFT(var, images, **assumptions)        
-        
 
     def DTFT(self, var=None, images=oo, **assumptions):
         """Convert to Fourier domain using discrete time Fourier transform."""
@@ -274,7 +354,7 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
 
         return DifferenceEquation(lhs, rhs, inputsym, outputsym)
 
-    def dlti_filter(self):
+    def dlti_filter(self, normalize_a0=True):
         """Create discrete-time linear time-invariant filter from discrete-time
         transfer function."""
 
@@ -287,16 +367,35 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
             
         N = self.N
         D = self.D
-        n_n = N.coeffs()
-        d_n = D.coeffs()
+        nn = N.coeffs()
+        dn = D.coeffs()
     
-        if len(n_n) > len(d_n):
+        if len(nn) > len(dn):
             raise ValueError("System not causal")
 
-        bn = (len(d_n) - len(n_n)) * [0] + n_n
-        an = d_n
+        bn = ExprList((len(dn) - len(nn)) * [0] + nn)
+        an = dn
+
+        if normalize_a0:
+            bn = [bx / an[0] for bx in bn]
+            an = [ax / an[0] for ax in an]
+        
         lpf = DLTIFilter(bn, an) 
         return lpf
+
+    def inverse_bilinear_transform(self):
+        """Approximate z = exp(s * dt)
+
+        by z = (1 + 0.5 * dt * s) / (1 - 0.5 * dt * s)"""
+
+        # TODO: add frequency warping as an option
+
+        from .symbols import s
+        from .discretetime import dt
+
+        a = s * dt / 2
+        
+        return self.subs((1 + a) / (1 - a))
         
 def zexpr(arg, **assumptions):
     """Create ZDomainExpression object.  If `arg` is zsym return z"""
@@ -316,7 +415,12 @@ def zexpr(arg, **assumptions):
 
 from .expressionclasses import expressionclasses
 
-expressionclasses.register('Z', ZDomainExpression)
+classes = expressionclasses.register('Z', ZDomainExpression)
+ZDomainVoltage = classes['voltage']
+ZDomainCurrent = classes['current']
+ZDomainAdmittance = classes['admittance']
+ZDomainImpedance = classes['impedance']
+ZDomainTransferFunction = classes['transfer']
 
 from .nexpr import DiscreteTimeDomainExpression, nexpr
 z = ZDomainExpression('z')
