@@ -8,7 +8,7 @@ from .transformer import UnilateralForwardTransformer
 from .ratfun import Ratfun
 from .sym import sympify, simplify, symsymbol, AppliedUndef
 from .utils import factor_const, scale_shift
-from .extrafunctions import UnitImpulse, UnitStep
+from .extrafunctions import UnitImpulse, UnitStep, dtrect
 import sympy as sym
 from sympy.simplify.fu import TR6, TR9
 
@@ -18,6 +18,9 @@ __all__ = ('ZT', )
 # Check the structure of the given expression
 def is_multiplied_with(expr, n, cmp, ret):
 
+    if expr.is_Piecewise:
+        return False
+    
     ret_flag = False   
     # Check for multiplication  with n
     if cmp == 'n' and expr == n:  #only n
@@ -55,7 +58,7 @@ def is_multiplied_with(expr, n, cmp, ret):
 
     # Check for multiplication with exp(b*n+c)        
     elif (cmp == 'exp(n)' and len(expr.args) == 1 and expr.is_Function and
-          expr.func == sym.exp):
+          ((expr.args[0]).as_poly(n)).is_linear and expr.func == sym.exp):
         ret += [expr]
         ret_flag = True
     elif cmp == 'exp(n)' and expr.is_Mul:   
@@ -66,13 +69,73 @@ def is_multiplied_with(expr, n, cmp, ret):
                 ret_flag = True
                 break                     
 
-    # Check for Multiplication with u(n-n0)
+    # Check for multiplication with u(n-n0)
+    elif (cmp == 'UnitStep' and len(expr.args) == 1 and expr.is_Function and  #step only
+          ((expr.args[0]).as_poly(n)).is_linear and expr.func in (sym.Heaviside, UnitStep) ):
+        ret += [expr]
+        ret_flag = True    
     elif cmp == 'UnitStep' and expr.is_Mul:
         for i in range(len(expr.args)):
-            if expr.args[i].is_Function and expr.args[i].func in (sym.Heaviside, UnitStep):
+            if expr.args[i].is_Function and expr.args[i].func in (sym.Heaviside, UnitStep) and ((expr.args[i].args[0]).as_poly(n)).is_linear:
                 ret += [expr.args[i]]   
                 ret_flag = True
                 break 
+   
+    # Check for multiplication with dtrect
+    elif (cmp =='rect' and len(expr.args) == 1 and expr.is_Function and
+          expr.func == dtrect and ((expr.args[0]).as_poly(n)).is_linear): 
+        ret += [expr]
+        ret_flag = True
+    elif cmp == 'rect' and expr.is_Mul:
+        for i in range(len(expr.args)):
+            if expr.args[i].is_Function and expr.args[i].func == dtrect and ((expr.args[i].args[0]).as_poly(n)).is_linear:        
+                ret += [expr.args[i]]   
+                ret_flag = True
+                break                
+   
+   # Check for multiplication with sin
+    elif (cmp == 'sin(n)' and len(expr.args) == 1 and expr.is_Function and # sin() only
+          ((expr.args[0]).as_poly(n)).is_linear and  expr.func == sym.sin):
+        ret += [expr]
+        ret_flag = True
+    elif cmp == 'sin(n)' and expr.is_Pow and expr.args[0].func==sym.sin  and (expr.args[0].args[0]).as_poly(n).is_linear:
+        ret += [expr.args[0]]
+        ret_flag = True        
+    elif cmp == 'sin(n)' and expr.is_Mul:   
+        for i in range(len(expr.args)):
+            if (expr.args[i].is_Function and expr.args[i].func == sym.sin and
+                ((expr.args[i].args[0]).as_poly(n)).is_linear):
+                ret += [expr.args[i]]   
+                ret_flag = True
+                break 
+            elif (expr.args[i].is_Pow and expr.args[i].args[0].func == sym.sin and
+                ((expr.args[i].args[0].args[0]).as_poly(n)).is_linear):
+                ret += [expr.args[i].args[0]]   
+                ret_flag = True                
+                break            
+            
+            
+    # Check for multiplication with cos
+    elif (cmp == 'cos(n)' and len(expr.args) == 1 and expr.is_Function and  # cos only
+          ((expr.args[0]).as_poly(n)).is_linear and expr.func == sym.cos):
+        ret += [expr]
+        ret_flag = True
+    elif cmp == 'cos(n)' and expr.is_Pow and expr.args[0].func==sym.cos  and (expr.args[0].args[0]).as_poly(n).is_linear: 
+        ret += [expr.args[0]]
+        ret_flag = True        
+    elif cmp == 'cos(n)' and expr.is_Mul:   
+        for i in range(len(expr.args)):
+            if (expr.args[i].is_Function and expr.args[i].func == sym.cos and
+                ((expr.args[i].args[0]).as_poly(n)).is_linear):
+                ret += [expr.args[i]]   
+                ret_flag = True
+                break    
+            elif (expr.args[i].is_Pow and expr.args[i].args[0].func == sym.cos and
+                ((expr.args[i].args[0].args[0]).as_poly(n)).is_linear):
+                ret += [expr.args[i].args[0]]   
+                ret_flag = True                
+                break            
+
 
     return ret_flag
 
@@ -91,12 +154,12 @@ class ZTransformer(UnilateralForwardTransformer):
         # This is needed to handle expressions like (2*n + 3)**2
         return sym.expand(expr)
     
-    def check(self, expr, n, z, **assumptions):
+    def check(self, expr, n, z, **kwargs):
 
         if expr.has(z):
             self.error('Expression depends on z')
 
-    def key(self, expr, n, z, **assumptions):
+    def key(self, expr, n, z, **kwargs):
         return expr, n, z,
 
     def func(self, expr, n, z):
@@ -309,21 +372,21 @@ class ZTransformer(UnilateralForwardTransformer):
 ztransformer = ZTransformer()
 
 
-def ZT(expr, n, z, evaluate=True, **assumptions):
+def ZT(expr, n, z, evaluate=True, **kwargs):
     """Compute unilateral Z-Transform transform of expr with lower limit 0.
 
     Undefined functions such as v[n] are converted to V(z)."""
     
     return ztransformer.transform(expr, n, z,
-                                  evaluate=evaluate, **assumptions)
+                                  evaluate=evaluate, **kwargs)
 
-def ztransform(expr, n, z, evaluate=True, **assumptions):
+def ztransform(expr, n, z, evaluate=True, **kwargs):
     """Compute unilateral Z-Transform transform of expr with lower limit 0.
 
     Undefined functions such as v[n] are converted to V(z)."""
 
     return ztransformer.transform(expr, n, z,
-                                  evaluate=evaluate, **assumptions)    
+                                  evaluate=evaluate, **kwargs)    
 
 
 from .expr import Expr
